@@ -1,5 +1,5 @@
 const ZQLExport: IZQL = class ZQL__2 {
-    private static requiredMap__0 = {
+    private static requiredMap = {
         [ZQLAction.QUERY]: [
             'tableName'
         ],
@@ -19,5 +19,5 @@ const ZQLExport: IZQL = class ZQL__2 {
             'keyword'
         ]
     };
-    private static zqlQueryTemplate__0: (...values: any[]) => string = ZQL__2.zqlTemplateParser`query ${'fnName'}${'fnName?.('}${'tableName'}${'fields?..'}${'fields'}${'fnName?.)'} ${'condition?.where'} ${'condition'} ${'restrictBy'} ${'returnWith'} ${'groupBy'} ${'orderBy'} ${'orderDirection'} ${'limit'} ${'offset'} ${'namedAs'}`;
+    private static zqlQueryTemplate: (...values: any[]) => string = ZQL__2.zqlTemplateParser`query ${'fnName'}${'fnName?.('}${'tableName'}${'fields?..'}${'fields'}${'fnName?.)'} ${'condition?.where'} ${'condition'} ${'restrictBy'} ${'returnWith'} ${'groupBy'} ${'orderBy'} ${'orderDirection'} ${'limit'} ${'offset'} ${'namedAs'}`;
 };
